from setuptools import setup

setup(name='kombustion',
      version='0.1',
      description='Eat a dict',
      url='https://github.com/eL0ck/Kombustion',
      author='eL0ck',
      author_email='tpj800@gmail.com',
      license='MIT',
      packages=['kombustion'],
      zip_safe=False)
